'use strict';

var path = require('node:path');
var core = require('@pkgr/core');
var tinyglobby = require('tinyglobby');

var _a;
const DEV = "development";
const PROD = "production";
const NODE_ENV = (_a = process.env.NODE_ENV) != null ? _a : DEV;
const __DEV__ = NODE_ENV === DEV;
const __PROD__ = NODE_ENV === PROD;
const NODE_MODULES_REG = /[/\\]node_modules[/\\]/;
const SCRIPT_RUNNERS = {
  npm: "npx",
  pnpm: "pnpm",
  yarn: "yarn",
  bun: "bun"
};
const SCRIPT_EXECUTORS = {
  npm: "npx",
  pnpm: "pnpx",
  // same as 'pnpm dlx'
  yarn: "yarn dlx",
  bun: "bunx"
};

const tryRequirePkg = (pkg) => {
  try {
    return core.cjsRequire(pkg);
  } catch (e) {
  }
};
const isTsAvailable = () => core.isPkgAvailable("typescript");
const isAngularAvailable = () => core.isPkgAvailable("@angular/core");
const isMdxAvailable = () => core.isPkgAvailable("@mdx-js/mdx") || core.isPkgAvailable("@mdx-js/react");
const isReactAvailable = () => core.isPkgAvailable("react");
const isSvelteAvailable = () => core.isPkgAvailable("svelte");
const isVueAvailable = () => core.isPkgAvailable("vue");
const tryGlob = (paths, options = {}) => {
  const {
    absolute = true,
    baseDir = core.CWD,
    ignore = ["**/node_modules/**"]
  } = typeof options === "string" ? { baseDir: options } : options;
  return paths.reduce(
    (acc, pkg) => [
      ...acc,
      ...tinyglobby.isDynamicPattern(pkg) ? tinyglobby.globSync(pkg, {
        cwd: baseDir,
        ignore,
        onlyFiles: false
      }).map((file) => absolute ? path.resolve(baseDir, file) : file) : [core.tryFile(pkg, true, baseDir)]
    ].filter(Boolean),
    []
  );
};
const identify = (_) => !!_;
const arrayify = (...args) => args.reduce((arr, curr) => {
  if (curr != null) {
    arr.push(
      ...Array.isArray(curr) ? curr.filter((it) => it != null) : [curr]
    );
  }
  return arr;
}, []);
const getPackageManager = () => {
  const execPath = process.env.npm_execpath;
  if (!execPath) {
    return;
  }
  if (/\byarn\b/.test(execPath)) {
    return "yarn";
  }
  if (/\bpnpm\b/.test(execPath)) {
    return "pnpm";
  }
  if (/\bnpm\b/.test(execPath)) {
    return "npm";
  }
  if (/\bbun\b/.test(execPath)) {
    return "bun";
  }
  console.warn("unknown package manager:", execPath);
};
const getScriptRunner = () => {
  const pm = getPackageManager();
  if (!pm) {
    return;
  }
  return SCRIPT_RUNNERS[pm];
};
const getScriptExecutor = () => {
  const pm = getPackageManager();
  if (!pm) {
    return;
  }
  return SCRIPT_EXECUTORS[pm];
};

const getPkgPaths = () => {
  var _a, _b, _c, _d;
  const pkg = (_a = tryRequirePkg(path.resolve("package.json"))) != null ? _a : {};
  const lernaConfig = (_b = tryRequirePkg(path.resolve("lerna.json"))) != null ? _b : {};
  return (_d = (_c = lernaConfig.packages) != null ? _c : pkg.workspaces) != null ? _d : [];
};
const isMonorepo = () => {
  const pkgPaths = getPkgPaths();
  return Array.isArray(pkgPaths) && pkgPaths.length > 0;
};
const getMonorepoPkgs = () => isMonorepo() ? tryGlob(
  getPkgPaths().map(
    (pkg) => pkg.endsWith("/package.json") ? pkg : `${pkg}/package.json`
  )
) : [];

exports.DEV = DEV;
exports.NODE_ENV = NODE_ENV;
exports.NODE_MODULES_REG = NODE_MODULES_REG;
exports.PROD = PROD;
exports.SCRIPT_EXECUTORS = SCRIPT_EXECUTORS;
exports.SCRIPT_RUNNERS = SCRIPT_RUNNERS;
exports.__DEV__ = __DEV__;
exports.__PROD__ = __PROD__;
exports.arrayify = arrayify;
exports.getMonorepoPkgs = getMonorepoPkgs;
exports.getPackageManager = getPackageManager;
exports.getScriptExecutor = getScriptExecutor;
exports.getScriptRunner = getScriptRunner;
exports.identify = identify;
exports.isAngularAvailable = isAngularAvailable;
exports.isMdxAvailable = isMdxAvailable;
exports.isMonorepo = isMonorepo;
exports.isReactAvailable = isReactAvailable;
exports.isSvelteAvailable = isSvelteAvailable;
exports.isTsAvailable = isTsAvailable;
exports.isVueAvailable = isVueAvailable;
exports.tryGlob = tryGlob;
exports.tryRequirePkg = tryRequirePkg;
Object.keys(core).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return core[k]; }
  });
});
